# financial-analysis

[![build-status][]][build-server]
[![PackageVersion][pypi-version]][pypi-home]
[![PythonVersion][python-version]][python-home]
[![Stable][pypi-status]][pypi-home]
[![Format][pypi-format]][pypi-home]
[![License][pypi-license]](LICENSE)

[build-status]: https://travis-ci.com/Kautenja/financial-analysis.svg
[build-server]: https://travis-ci.com/Kautenja/financial-analysis
[pypi-version]: https://badge.fury.io/py/financial-analysis.svg
[pypi-license]: https://img.shields.io/pypi/l/financial-analysis.svg
[pypi-status]: https://img.shields.io/pypi/status/financial-analysis.svg
[pypi-format]: https://img.shields.io/pypi/format/financial-analysis.svg
[pypi-home]: https://badge.fury.io/py/financial-analysis
[python-version]: https://img.shields.io/pypi/pyversions/financial-analysis.svg
[python-home]: https://python.org

A package for performing basic financial analysis functions.

[pandas]: https://pandas.pydata.org/

## Installation

The preferred installation of `financial-analysis` is from `pip`:

```shell
pip install financial-analysis
```

## Testing

To run the Python unit-test suite, run:

```shell
python -m unittest discover .
```

## Usage

TODO
